@@ -1,4 +1,6 @@
+from .chartdata import ChartData
 from .ticker import Ticker
 from .search import Search
-from . import chartdata, collection
+from .news import News
+from . import collection
 from ._version import __version__
